# encoding: utf-8
#
# Redmine - project management software
# Copyright (C) 2006-2012  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

module ContextMenusHelper
  def context_menu_link(name, url, options={})
    options[:class] ||= ''
    if options.delete(:selected)
      options[:class] << ' icon-checked disabled'
      options[:disabled] = true
    end
    if options.delete(:disabled)
      options.delete(:method)
      options.delete(:confirm)
      options.delete(:onclick)
      options[:class] << ' disabled'
      url = '#'
    end
    link_to h(name), url, options
  end

  def bulk_update_custom_field_context_menu_link(field, text, value)
    context_menu_link h(text),
      {:controller => 'issues', :action => 'bulk_update', :ids => @issues.collect(&:id), :issue => {'custom_field_values' => {field.id => value}}, :back_url => @back},
      :method => :post,
      :selected => (@issue && @issue.custom_field_value(field) == value)
  end
  
  def wacher_list(context={})

    ret_str=''

    watched_list=[]
    nonwatched_list=[]
    target_project=context[:issues][0].project
    menu_exists=false

    context[:issues].each do |issue|
      if issue.author != User.current
        issue.watched_by?(User.current) ? watched_list << issue : nonwatched_list << issue
      end
      target_project=nil if target_project!=nil && issue.project!=target_project
    end

    ret_str << "<li class=\"folder\">"
    ret_str << "<a href=\"#\" class=\"submenu\" onclick=\"return false;\">#{l(:label_issue_watchers)}</a>"
    ret_str << '<ul>'

    if target_project && User.current.allowed_to?(:add_issue_watchers,target_project)
      ret_str << "<li>#{context_menu_link("#{l(:permission_add_issue_watchers)}",
                        {:controller => 'context_menu_watchers', :action => 'manage_watchers_bulk', :issues => context[:issues], :back_url => context[:back]})}</li>"
      menu_exists=true
    end

    if target_project && User.current.allowed_to?(:delete_issue_watchers,target_project)
      ret_str << "<li>#{context_menu_link("#{l(:permission_delete_issue_watchers)}",
                        {:controller => 'context_menu_watchers', :action => 'manage_watchers_bulk', :unwatch => true, :issues => context[:issues], :back_url => context[:back]})}</li>"
      menu_exists=true
    end

    if nonwatched_list.size > 0
      ret_str << "<li>#{context_menu_link("#{l(:button_watch)}",
                        {:controller => 'context_menu_watchers', :action => 'watch_bulk', :issues => nonwatched_list.collect(&:id), :back_url => context[:back]},
                        :class => 'icon icon-fav')}</li>"
      menu_exists=true
    end
    if watched_list.size > 0
      ret_str << "<li>#{context_menu_link("#{l(:button_unwatch)}",
                        {:controller => 'context_menu_watchers', :action => 'watch_bulk', :issues => watched_list.collect(&:id), :back_url => context[:back], :unwatch => true},
                        :class => 'icon icon-fav-off')}</li>"
      menu_exists=true
    end

    ret_str << "</ul></li>"

    ret_str='' unless menu_exists

    return ret_str
  end

end

